# Generated by Django 2.1 on 2018-08-07 20:53

from django.conf import settings
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import re


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='FavoriteSpot',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
        ),
        migrations.CreateModel(
            name='Item',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=50)),
                ('slug', models.SlugField(blank=True)),
                ('item_category', models.CharField(max_length=50, null=True)),
                ('item_subcategory', models.CharField(max_length=50, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='ItemExtendedInfo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key', models.CharField(max_length=50)),
                ('value', models.CharField(max_length=350)),
                ('item', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='spotseeker_server.Item')),
            ],
            options={
                'verbose_name_plural': 'Item extended info',
            },
        ),
        migrations.CreateModel(
            name='ItemImage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('description', models.CharField(blank=True, max_length=200)),
                ('display_index', models.PositiveIntegerField(blank=True, null=True)),
                ('image', models.ImageField(upload_to='item_images')),
                ('content_type', models.CharField(max_length=40)),
                ('width', models.IntegerField()),
                ('height', models.IntegerField()),
                ('creation_date', models.DateTimeField(auto_now_add=True)),
                ('modification_date', models.DateTimeField(auto_now=True)),
                ('etag', models.CharField(max_length=40)),
                ('upload_user', models.CharField(max_length=40)),
                ('upload_application', models.CharField(max_length=100)),
                ('item', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='spotseeker_server.Item')),
            ],
        ),
        migrations.CreateModel(
            name='SharedSpace',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('user', models.CharField(max_length=16)),
                ('sender', models.CharField(max_length=256)),
            ],
        ),
        migrations.CreateModel(
            name='SharedSpaceRecipient',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('hash_key', models.CharField(max_length=32)),
                ('recipient', models.CharField(max_length=256)),
                ('user', models.CharField(blank=True, default=None, max_length=16, null=True)),
                ('date_shared', models.DateTimeField(auto_now_add=True)),
                ('shared_count', models.IntegerField()),
                ('date_first_viewed', models.DateTimeField(null=True)),
                ('viewed_count', models.IntegerField()),
                ('shared_space', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='spotseeker_server.SharedSpace')),
            ],
        ),
        migrations.CreateModel(
            name='SpaceReview',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('review', models.CharField(default='', max_length=1000)),
                ('original_review', models.CharField(default='', max_length=1000)),
                ('rating', models.IntegerField(validators=[django.core.validators.MaxValueValidator(5), django.core.validators.MinValueValidator(1)])),
                ('date_submitted', models.DateTimeField(auto_now_add=True)),
                ('date_published', models.DateTimeField(null=True)),
                ('is_published', models.BooleanField(default=False)),
                ('is_deleted', models.BooleanField(default=False)),
                ('published_by', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='published_by', to=settings.AUTH_USER_MODEL)),
                ('reviewer', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='reviewer', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='Spot',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=100)),
                ('latitude', models.DecimalField(decimal_places=8, max_digits=11, null=True)),
                ('longitude', models.DecimalField(decimal_places=8, max_digits=11, null=True)),
                ('height_from_sea_level', models.DecimalField(blank=True, decimal_places=8, max_digits=11, null=True)),
                ('building_name', models.CharField(blank=True, max_length=100)),
                ('floor', models.CharField(blank=True, max_length=50)),
                ('room_number', models.CharField(blank=True, max_length=25)),
                ('capacity', models.IntegerField(blank=True, null=True)),
                ('display_access_restrictions', models.CharField(blank=True, max_length=200)),
                ('organization', models.CharField(blank=True, max_length=50)),
                ('manager', models.CharField(blank=True, max_length=50)),
                ('etag', models.CharField(max_length=40)),
                ('last_modified', models.DateTimeField(auto_now=True)),
                ('external_id', models.CharField(blank=True, default=None, max_length=100, null=True, unique=True, validators=[django.core.validators.RegexValidator(re.compile('^[-a-zA-Z0-9_]+\\Z'), "Enter a valid 'slug' consisting of letters, numbers, underscores or hyphens.", 'invalid')])),
            ],
        ),
        migrations.CreateModel(
            name='SpotAvailableHours',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('day', models.CharField(choices=[('m', 'monday'), ('t', 'tuesday'), ('w', 'wednesday'), ('th', 'thursday'), ('f', 'friday'), ('sa', 'saturday'), ('su', 'sunday')], max_length=3)),
                ('start_time', models.TimeField()),
                ('end_time', models.TimeField()),
                ('spot', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='spotseeker_server.Spot')),
            ],
            options={
                'verbose_name_plural': 'Spot available hours',
            },
        ),
        migrations.CreateModel(
            name='SpotExtendedInfo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key', models.CharField(max_length=50)),
                ('value', models.CharField(max_length=350)),
                ('spot', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='spotseeker_server.Spot')),
            ],
            options={
                'verbose_name_plural': 'Spot extended info',
            },
        ),
        migrations.CreateModel(
            name='SpotImage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('description', models.CharField(blank=True, max_length=200)),
                ('display_index', models.PositiveIntegerField(blank=True, null=True)),
                ('image', models.ImageField(upload_to='space_images')),
                ('content_type', models.CharField(max_length=40)),
                ('width', models.IntegerField()),
                ('height', models.IntegerField()),
                ('creation_date', models.DateTimeField(auto_now_add=True)),
                ('modification_date', models.DateTimeField(auto_now=True)),
                ('etag', models.CharField(max_length=40)),
                ('upload_user', models.CharField(max_length=40)),
                ('upload_application', models.CharField(max_length=100)),
                ('spot', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='spotseeker_server.Spot')),
            ],
        ),
        migrations.CreateModel(
            name='SpotType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.SlugField()),
            ],
        ),
        migrations.AddField(
            model_name='spot',
            name='spottypes',
            field=models.ManyToManyField(blank=True, max_length=50, related_name='spots', to='spotseeker_server.SpotType'),
        ),
        migrations.AddField(
            model_name='spacereview',
            name='space',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='spotseeker_server.Spot'),
        ),
        migrations.AddField(
            model_name='sharedspace',
            name='space',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='spotseeker_server.Spot'),
        ),
        migrations.AddField(
            model_name='item',
            name='spot',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='spotseeker_server.Spot'),
        ),
        migrations.AddField(
            model_name='favoritespot',
            name='spot',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='spotseeker_server.Spot'),
        ),
        migrations.AddField(
            model_name='favoritespot',
            name='user',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterUniqueTogether(
            name='spotextendedinfo',
            unique_together={('spot', 'key')},
        ),
        migrations.AlterUniqueTogether(
            name='itemextendedinfo',
            unique_together={('item', 'key')},
        ),
    ]
